## 10.2 Mehr als zwei Zeitpunkte
data.a_w <- read_excel("rep_anova.xlsx", na="NA", col_names=TRUE)
data.a_l <- pivot_longer(data.a_w, T0:T2, names_to="Zeitpunkt", values_to="Wert")
data.a_l$Zeitpunkt <- as.factor(data.a_l$Zeitpunkt)

# 10.2.1 ANOVA mit Messwiederholung
####################################
# Deskriptive Voranalyse
library(dplyr)
data.a_l %>%
  group_by(Zeitpunkt) %>%
  summarize(M = mean(Wert),
            SD = sd(Wert),
            N = n()) %>%
  as.data.frame()

# Boxplots
boxplot(data.a_l$Wert~data.a_l$Zeitpunkt)

# Prüfung auf Ausreißer
library(dplyr)
library(rstatix)
data.a_l %>%
  group_by(Zeitpunkt) %>%
  identify_outliers(Wert) %>%
  as.data.frame()

# Prüfung auf Normalverteilung
library(ggpubr)
ggqqplot(data.a_l, "Wert", facet.by = "Zeitpunkt")

# Durchführung der ANOVA mit Messwiederholung und speichern der Ergebnisse in seperatem Objekt
rep_anova <- anova_test(data = data.a_l, dv = Wert, wid = ID, within = Zeitpunkt, effect.size = "pes")

# Mauchly's Test auf Sphärizität ausgeben
rep_anova$`Mauchly's Test for Sphericity`

# ANOVA-Ergebnisse ausgeben
get_anova_table(rep_anova)

# post-hoc-Tests (paarweise t-Tests) bei signifikanter ANOVA
data.a_l %>%
  pairwise_t_test(Wert~Zeitpunkt, paired = TRUE, p.adjust.method = "bonferroni") %>%
  as.data.frame()

# Effektstärke für signifikante post-hoc-Tests
data.a_l %>%
  cohens_d(Wert~Zeitpunkt, paired = TRUE) %>%
  as.data.frame()


# 10.2.2 Friedman-ANOVA
#######################
data.a_w <- read_excel("rep_anova.xlsx", na="NA", col_names=TRUE)
data.a_l <- pivot_longer(data.a_w, T0:T2, names_to="Zeitpunkt", values_to="Wert")
data.a_l$Zeitpunkt <- as.factor(data.a_l$Zeitpunkt)

# Deskriptive Voranalyse
library(dplyr)
data.a_l %>%
 group_by(Zeitpunkt) %>%
 summarize(Q1 = quantile(Wert, probs = 0.25),
           Q2 = quantile(Wert, probs = 0.5),
           Q3 = quantile(Wert, probs = 0.75),
           IQR = IQR(Wert)) %>%
 as.data.frame()

# Boxplots
boxplot(data.a_l$Wert~data.a_l$Zeitpunkt)

# Friedman-Test rechnen
friedman_test(Wert ~ Zeitpunkt | ID, data = data.a_l)

# post-hoc-Test (paarweise abhängige Wilcoxon-Tests) bei signifikanter Friedman-ANOVA
data.a_l %>%
  wilcox_test(Wert~Zeitpunkt, paired = TRUE, p.adjust.method = "bonferroni") %>%
  as.data.frame()

# Effektstärke der Friedman-ANOVA berechnen (eher unüblich)
friedman_effsize(Wert ~ Zeitpunkt | ID, data = data.a_l)

# Effektstärke für signifikante post-hoc-Tests
data.a_l %>%
  wilcox_effsize(Wert ~ Zeitpunkt, paired = TRUE)%>%
  as.data.frame()
