## 11.1 Unterschiede zwischen 2 Gruppen
  # 11.1.1 t-Test bei unabhängigen Stichproben
##############################################
data.t2 <- read_excel("t_test_unabhSP.xlsx", na="NA", col_names=TRUE)
data.t2$Gruppe <- as.factor(data.t2$Gruppe)

# Deskriptive Voranalyse
library(dplyr)
data.t2 %>%
 group_by(Gruppe) %>%
 summarize(M = mean(Wert),
           SD = sd(Wert),
           N = n()) %>%
 as.data.frame()

library(psych)
describeBy(data.t2$Wert, data.t2$Gruppe)

# Boxplots
boxplot(data.t2$Wert~data.t2$Gruppe)

# Prüfung auf Normalverteilung
library(ggpubr)
ggqqplot(data.t2, "Wert", facet.by = "Gruppe")

# Prüfung auf Varianzhomogenität
library(car)
leveneTest(data = data.t2, Wert~Gruppe)

# Berechnung t-Test
# Zweiseitige Testung
t.test(data = data.t2, Wert~Gruppe, var.equal = TRUE)

# Einseitige Testung
t.test(data = data.t2, Wert~Gruppe, var.equal = TRUE, alternative = "greater")

# Berechnung Effektstärke bei signifikantem Ergebnis
library(lsr)
cohensD(data = data.t2, Wert~Gruppe)

  # 11.1.2 Mann-Whitney-U-Test (Mann-Whitney-Wilcoxon-Test)
##############################################
data.m <- read_excel("mwu_test.xlsx", na="NA", col_names=TRUE)
data.m$Gruppe <- as.factor(data.m$Gruppe)

# Deskriptive Voranalyse
library(dplyr)
 data.m %>%
 group_by(Gruppe) %>%
 summarize(Q1 = quantile(Wert, probs = 0.25),
           Q2 = quantile(Wert, probs = 0.5),
           Q3 = quantile(Wert, probs = 0.75),
           IQR = IQR(Wert),
           N = n()) %>%
  as.data.frame()

# Boxplots
boxplot(data.m$Wert~data.m$Gruppe)

# Zweiseitige Testung
wilcox.test(data.m$Wert~data.m$Gruppe, exact = FALSE, conf.int = TRUE)

# Einseitige Testung
wilcox.test(data = data.m, Wert~Gruppe, conf.int = TRUE, alternative = "greater")

# Effektstärke berechnen
library(rstatix)
wilcox_effsize(data = data.m, Wert~Gruppe)

# p-Wert ermitteln
x <- wilcox.test(data.m$Wert~data.m$Gruppe, exact = FALSE)
qnorm(x$p.value)
