## 11.1 Unterschiede zwischen mehr als 2 Gruppen
# 11.1.1 Einfaktorielle ANOVA
#############################
data.a <- read_excel("anova.xlsx", na="NA", col_names=TRUE)
data.a$Gruppe <- as.factor(data.a$Gruppe)

# Deskriptive Voranalyse
data.a %>%
  group_by(Gruppe) %>%
  summarize(M = mean(Wert),
            SD = sd(Wert),
            N = n()) %>%
  as.data.frame()

library(psych)
describeBy(data.a$Wert, group = data.a$Gruppe)

# Boxplots
boxplot(data.a$Wert~data.a$Gruppe)

# Normalverteilung prüfen
nv <- lm(Wert ~ Gruppe, data = data.a)
library(ggpubr)
ggqqplot(residuals(nv))

# Varianzhomogenität prüfen
library(car)
leveneTest(data = data.a, Wert~Gruppe)
plot(nv,1)

# Berechnung der ANOVA
anova_test(data = data.a, dv = Wert, between = Gruppe, effect.size = "pes")

# post-hoc-Tests bei signifikanter ANOVA
data.a %>%
  pairwise_t_test(Wert~Gruppe, pool.sd = TRUE,p.adjust.method = "bonferroni") %>%
  as.data.frame()

# Berechnung Effektstärken bei signifikanten post-Hoc-Tests
data.a %>%
  cohens_d(Wert~Gruppe)%>%
  as.data.frame()

# 11.2.2 Kruskal-Wallis-Test
############################
data.k <- read_excel("kruskal.xlsx", na="NA", col_names=TRUE)
data.k$Gruppe <- as.factor(data.k$Gruppe)

library(dplyr)
data.k %>%
 group_by(Gruppe) %>%
 summarize(Q1 = quantile(Wert, probs = 0.25),
           Q2 = quantile(Wert, probs = 0.5),
           Q3 = quantile(Wert, probs = 0.75),
           IQR = IQR(Wert),
           N = n()) %>%
  as.data.frame()

library(psych)
describeBy(data.k$Wert, group = data.k$Gruppe)           
           
# Boxplots 
boxplot(data.k$Wert~data.k$Gruppe)

# Kruskal-Wallis-Test berechnen
kruskal_test(Wert ~ Gruppe, data = data.k)

# post-hoc-Test bei signifikantem Kruskal-Wallis-Test
data.k %>%
  wilcox_test(Wert~Gruppe, p.adjust.method = "bonferroni") %>%
  as.data.frame()

# Effektstärke Kruskal-Wallis-Test (unüblich)
kruskal_effsize(Wert ~ Gruppe, data = data.k)

# Effektstärke bei signifikanten post-hoc-Tests
data.k %>%
  wilcox_effsize(Wert ~ Gruppe) %>%
  as.data.frame()
