## 12.1 Mehrfaktorielle ANOVA
data.a2 <- read_excel("anova2.xlsx", na="NA", col_names=TRUE)
data.a2$Erfahrung <- as.factor(data.a2$Erfahrung)
data.a2$Geschlecht <- as.factor(data.a2$Geschlecht)

# Deskriptive Voranalyse
data.a2 %>%
 group_by(Geschlecht, Erfahrung) %>%
 summarize(M = mean(Einkommen),
           SD = sd(Einkommen),
           N = n()) %>%
  as.data.frame()

library(psych)
describeBy(data.a$Wert, group = data.a$Gruppe)

# Boxplots
llibrary(ggpubr)
ggboxplot(data.a2, x = "Erfahrung", y = "Einkommen", fill = "Geschlecht")

# Normalverteilung prüfen
nv <- lm(Einkommen ~ Geschlecht*Erfahrung, data = data.a2)
library(ggpubr)
ggqqplot(residuals(nv))

# Varianzhomogenität prüfen
library(car)
leveneTest(data = data.a2, Einkommen~Geschlecht*Erfahrung)
plot(nv,1)

# Mehrfaktorielle ANOVA rechnen
anova_test(data = data.a2, Einkommen~Geschlecht*Erfahrung, effect.size = "pes")

# post-hoc-Tests bei signifikanter ANOVA rechnen
data.a2 %>%
  pairwise_t_test(Einkommen~Erfahrung, pool.sd = TRUE, p.adjust.method = "bonferroni") %>%
  as.data.frame()

# A) Einfaktorielle ANOVA je Geschlecht - bei signifikanter Interaktion (Geschlecht*Erfahrung)
data.a2 %>%
  group_by(Geschlecht) %>%
  anova_test(Einkommen ~ Erfahrung, effect.size = "pes")%>%
  as.data.frame()

# B) Einfaktorielle ANOVA je Erfahrungsstufe - bei signifikanter Interaktion (Geschlecht*Erfahrung)
data.a2 %>%
  group_by(Erfahrung) %>%
  anova_test(Einkommen ~ Geschlecht, effect.size = "pes")%>%
  as.data.frame()

# Post-hoc-Analyse ANOVAs aus A) und B)
install.packages("emmeans")
 library(emmeans)
 data.a2 %>%
 group_by(Geschlecht) %>%
 emmeans_test(Einkommen ~ Erfahrung, p.adjust.method = "bonferroni") %>%
 as.data.frame()
 
ph <- data.a2 %>%
  group_by(Geschlecht) %>%
  emmeans_test(Einkommen~Erfahrung, 
               p.adjust.method = "bonferroni") %>%
  add_xy_position(x = "Geschlecht")

ggboxplot(data.a2, x = "Geschlecht", y = "Einkommen", color = "Erfahrung") +
  stat_pvalue_manual(ph) +
  labs(subtitle = get_test_label(anova_test(data = data.a2, Einkommen~Geschlecht*Erfahrung, effect.size = "pes"), detailed = TRUE))
