## 12.2 Gemischte ANOVA
rep_cont <- read_excel("reps_cont.xlsx", na="NA", col_names=TRUE)
library(tidyr)
rep_cont_long <- pivot_longer(rep_cont, T0:T4, names_to="Zeitpunkt", values_to="Wert")
rep_cont_long$Gruppe[rep_cont_long$Gruppe == "1"] <- "KG"
rep_cont_long$Gruppe[rep_cont_long$Gruppe == "2"] <- "EG"
rep_cont_long$Gruppe <- as.factor(rep_cont_long$Gruppe)
rep_cont_long$Zeitpunkt <- as.factor(rep_cont_long$Zeitpunkt)
data.ma <- rep_cont_long

# Deskriptive Analyse
library(dplyr)
 data.ma %>%
 group_by(Zeitpunkt, Gruppe) %>%
 get_summary_stats(Wert, type = "mean_sd") %>%
 as.data.frame()

# Boxplots
library(ggpubr)
ggboxplot(data.ma, x = "Zeitpunkt", y = "Wert", fill = "Gruppe")

# Prüfung auf Normalverteilung
library(ggpubr)
ggqqplot(data.ma, "Wert", facet.by = "Zeitpunkt*Gruppe")

# Prüfung auf Varianzhomogenität
library(rstatix)
data.ma %>%
 group_by(Zeitpunkt) %>%
 levene_test(Wert~Gruppe)

# Prüfung auf Gleichheit der Kovarianzmatrizen
box_m(data.ma[, "Wert", drop = FALSE], data.ma$Gruppe)

# Prüfung auf Ausreißer
data.ma %>%
  group_by(Gruppe, Zeitpunkt) %>%
  identify_outliers(Wert)

# (A) 2 Gruppen – paarweise t-Tests 
data.ma %>%
 group_by(Zeitpunkt)%>%
 pairwise_t_test(Wert~Gruppe, pool.sd = TRUE, p.adjust.method = "bonferroni") %>%
 as.data.frame()

# (B) > 2 Gruppen - ANOVA
data.ma %>%
 group_by(Zeitpunkt) %>%
 anova_test(dv = Wert, wid = ID, between= Gruppe)%>%
 get_anova_table()%>%
 adjust_pvalue(method = "bonferroni")%>%
 as.data.frame()


# bei Signifikanz der ANOVA (B) wird der Code bei (A) zusätzlich gerechnet

# (A) Zeiteffekt
data.ma %>%
 pairwise_t_test(Wert~Zeitpunkt, pool.sd = TRUE, paired = TRUE, p.adjust.method = "bonferroni") %>%
 as.data.frame()

# (B) Gruppeneffekt
data.ma %>%
 pairwise_t_test(Wert~Gruppe, pool.sd = TRUE, p.adjust.method = "bonferroni") %>%
 as.data.frame()

# grafische Darstellung
ggline(data.ma, x = "Zeitpunkt", y = "Wert", color = "Gruppe",
       add = "mean_se", palette = c("black", "grey"))
