# 13 Korrelation

data <- read.csv2("data.csv", na = "NA", dec = ",", header=TRUE)
data$Lieblingsfarbe <- as.factor(data$Lieblingsfarbe)
data$Geschlecht[data$Geschlecht == "0"] <- "Mann"
data$Geschlecht[data$Geschlecht == "1"] <- "Frau"
data$Geschlecht <- as.factor(data$Geschlecht)

# 13.1 Pearson-Korrelation
##########################
cor.test(data$Zufriedenheit, data$Einkommen)


# 13.2 Spearman-Korrelation
###########################
cor.test(data$Zufriedenheit, data$Einkommen, method = "spearman")

library(rstatix)
cor_test(data$Zufriedenheit, data$Einkommen, method = "spearman")

# Konfidenzintervalle anfordern
library(DescTools)
SpearmanRho(data$Zufriedenheit, data$Einkommen, conf.level = 0.95)


# 13.3 Kendall-Tau-Korrelation
##############################
cor.test(data$Zufriedenheit, data$Einkommen, method = "kendall")

# Konfidenzintervalle anfordern
library(DescTools)
KendallTauB(data$Zufriedenheit, data$Einkommen, conf.level = 0.95)

# 13.4 Pearson-punktbiseriale Korrelation
#########################################
data$Geschlecht <- as.numeric(data$Geschlecht)
cor.test(data$Geschlecht, data$Zufriedenheit)


# 13.5 Chi2-Test auf Unabhängigkeit
###################################
library(gmodels)
CrossTable(data$Lieblingsfarbe, data$Geschlecht,
           prop.c = FALSE, prop.r = FALSE, prop.t = FALSE,
           expected=TRUE, fisher=TRUE)

# Effektstärke bei signifikantem Test
library(rcompanion)
cohenW(data$Geschlecht, data$Lieblingsfarbe)


# 13.6 Kontingenzkoeffizient / Cramer V
#######################################
library(DescTools)
Assocs(table(data$Geschlecht, data$Lieblingsfarbe))


# 13.7 Odds Ratio
#################
data.o <- read_excel("odds.xlsx", na="NA", col_names=TRUE)
data.o$Raucher = factor(data.o$Raucher, levels = c(0,1), labels = c("Nichtraucher", "Raucher"))
data.o$Atembeschwerden <- factor(data.o$Atembeschwerden, levels = c(0,1), labels = c("Keine Beschwerden", "Beschwerden"))

# Kreuztabelle erstellen
table(data.o$Raucher, data.o$Atembeschwerden)

# Odds Ratio berechnen
library(DescTools)
OddsRatio(table(data.o$Raucher, data.o$Atembeschwerden))


# 13.8 Partialkorrelation
#########################
# Teildatensatz erstellen
data2 <- subset(data, select = c(Einkommen, Bildungsjahre, Motivation))

# Bivariate Korrelationsmatrix
cor(data2)

# Partialkorrelationsmatrix
partial.r(data2, cs(Einkommen, Bildungsjahre), cs(Motivation), method="pearson")