## 14.1 Lineare Regression

data <- read.csv2("data.csv", na = "NA", dec = ",", header=TRUE)
data$Lieblingsfarbe <- as.factor(data$Lieblingsfarbe)
data$Geschlecht[data$Geschlecht == "0"] <- "Mann"
data$Geschlecht[data$Geschlecht == "1"] <- "Frau"
data$Geschlecht <- as.factor(data$Geschlecht)

# Modellbildung
modell <- lm(Einkommen ~ IQ + Bildungsjahre + Motivation +
             Geschlecht + Erfahrung, data = data)

# Multikollinearität testen
library(car)
round(vif(modell),3)

# Auf einflussreiche Fälle prüfen
plot(modell, 4)

# Normalverteilung der Residuen prüfen
plot(modell, 2)
hist(residuals(modell))

# Homoskedastizität prüfen
# Grafisch - zu bevorzugende Variante
plot(modell, 1)

# Ergebnisse der Regression ausgeben lassen
summary(modell)

# robuste Standardfehler
install.packages("lmtest")
library(lmtest)
library(sandwich)
coeftest(modell, vcov = vcovHC(modell, type = "HC3"))

# Standardisierte Koeffizienten ausgeben
  # Daten erneut einlesen, da Geschlecht hier zwingend numerisch vorliegen muss
data <- read.csv2("data.csv", na = "NA", dec = ",", header=TRUE)
  # Modell erneut rechnen
zmodell <- lm(scale(Einkommen) ~ scale(IQ) + scale(Bildungsjahre) + scale(Motivation) + scale(Geschlecht) + scale(Erfahrung), data = data)
zmodell$coefficients
# auf 3 Nachkommastellen gerundet
round(zmodell$coefficients,3)


# Ausgabe der Ergebnisse mittels stargazer
install.packages("stargazer")
library(stargazer)
stargazer(modell, title = "Regressionsergebnisse", style = "all", decimal.mark = ",", out = "reg.html")
