## 6.1 Histogramme
data <- read.csv2("data.csv", na = "NA", dec = ",", header=TRUE)
data$Lieblingsfarbe <- as.factor(data$Lieblingsfarbe)
data$Geschlecht[data$Geschlecht == "0"] <- "Mann"
data$Geschlecht[data$Geschlecht == "1"] <- "Frau"
data$Geschlecht <- as.factor(data$Geschlecht)

# 6.1.1 mit baseR
# Histogramm
h<- hist(data$Einkommen, main = "BEISPIELTITEL", ylab = "Häufigkeit", xlab = "Einkommen", col = "steelblue")

# Hinzufügen von Zählungen
text(h$mids, h$counts, labels = h$counts, adj = c(0.5, -0.5))


# 6.1.2 mit dem Paket ggplot2
install.packages("ggplot2")
library(ggplot2)
# (A) Histogramm für metrische Variablen
ggplot(data, aes(x = Einkommen)) +
  geom_histogram(binwidth = 1000)

# (B) Histogramm für kategoriale Variablen
ggplot(data, aes(x = Lieblingsfarbe)) +
 geom_histogram(stat = "count")

# Histogramm mit Zählungen
ggplot(data, aes(x = Einkommen,label = ..count..)) +
 geom_histogram(binwidth = 1000, color = "white", fill = "steelblue")+
 labs(x = "Einkommen", y = "Häufigkeit") +
 ggtitle("Histogramm für Einkommen") +
 geom_text(stat = "bin", vjust = -0.5, binwidth = 1000, position = "stack")+
 theme(plot.title = element_text(hjust = 0.5))


# (A) Normalverteilungskurve
ggplot(data, aes(x = Einkommen))+
 geom_histogram(binwidth = 1000, aes(y = ..density..), fill = "steelblue", color = "grey")+
 labs(x = "Einkommen", y = "Dichte") +
 stat_function(fun = dnorm, args = list(mean = mean(data$Einkommen), sd = sd(data$Einkommen)),
               color = "black", size = 1)+
 ggtitle("Histogramm für Einkommen") +
 theme(plot.title = element_text(hjust = 0.5))

# (B) Dichtefunktion
ggplot(data, aes(x = Einkommen))+
 geom_histogram(binwidth = 1000, fill = "steelblue", color = "grey")+
 labs(x = "Einkommen", y = "Dichte") +
 geom_density(aes(y = ..density.. * (nrow(data)*1000)), color = "black", size = 1)+
 ggtitle("Histogramm für Einkommen") +
 theme(plot.title = element_text(hjust = 0.5))

# Designvorlagen anwenden
ggplot(data, aes(x = Lieblingsfarbe)) +
  geom_histogram(stat = "count")+
  theme_minimal()

# 6.1.3 Histogramm für Gruppen mit ggplot2
ggplot(data, aes(x = Einkommen, color = Geschlecht, fill = Geschlecht)) +
       geom_histogram(binwidth = 1000, position = "stack", color = "white")

ggplot(data, aes(x = Einkommen, fill = Geschlecht, label = ..count..)) +
       geom_histogram(binwidth = 1000, position = "stack", color = "white")+
       labs(x = "Einkommen je Geschlecht", y = "Häufigkeit") +
       ggtitle("Histogramm") +
       theme(plot.title = element_text(hjust = 0.5),
       legend.position = "bottom")+
       geom_text(stat = "bin", vjust = -0.5, binwidth = 1000,
       position = "stack", color = "black" )+
       scale_fill_manual(labels = c("Weiblich", "Männlich"), values = c("darkred", "steelblue"))
