## 6.2 Säulendiagramme

data <- read.csv2("data.csv", na = "NA", dec = ",", header=TRUE)
data$Lieblingsfarbe <- as.factor(data$Lieblingsfarbe)
data$Geschlecht[data$Geschlecht == "0"] <- "Mann"
data$Geschlecht[data$Geschlecht == "1"] <- "Frau"
data$Geschlecht <- as.factor(data$Geschlecht)

# 6.2.1 mit baseR
# ohne Farben
barplot(table(data$Lieblingsfarbe))
# eingefärbt
barplot(table(data$Lieblingsfarbe),
        xlab = "Farben", ylab = "Häufigkeit",
        main = "Lieblingsfarben",
        col = c("blue", "yellow", "green", "red", "black"))

# (A) Gestapelte Säulen – Farben werden je Geschlecht gestapelt
barplot(table(data$Lieblingsfarbe, data$Geschlecht),
        col = c("blue", "yellow", "green", "red", "black"))
# (B) Gestapelte Säulen – Je Farbe werden die Anzahl der Geschlechtsausprägungen gestapelt
barplot(table(data$Geschlecht, data$Lieblingsfarbe),
        col = c("darkblue", "darkred"))
# (C) Gruppierte Säulen – Je Geschlecht hat jede Farbe eine Säule
barplot(table(data$Lieblingsfarbe, data$Geschlecht), beside = TRUE,
        col = c("blue", "yellow", "green", "red", "black"))
# (D) Gruppierte Säulen – Je Farbe werden die Anzahl der Geschlechtsausprägungen in einer separaten Säule abgetragen
barplot(table(data$Geschlecht, data$Lieblingsfarbe), beside = TRUE,
        col = c("darkblue", "darkred"))

# 6.2.2 mit dem Paket ggplot2
# ohne Farben
ggplot(data, aes(x = Lieblingsfarbe,label = ..count..))+
       geom_bar()+
       labs(x = "Lieblingsfarbe", y = "Häufigkeit") +
       ggtitle("Säulendiagramm") +
       geom_text(stat = "count", vjust = -0.5)+
       theme(plot.title = element_text(hjust = 0.5))

# eingefärbt
ggplot(data, aes(x = Lieblingsfarbe,label = ..count..))+
  geom_bar(fill = c("steelblue", "gold", "darkgreen", "darkred", "black"))
  labs(x = "Lieblingsfarbe", y = "Häufigkeit") +
  ggtitle("Säulendiagramm") +
  geom_text(stat = "count", vjust = -0.5)+
  theme(plot.title = element_text(hjust = 0.5))

# 6.2.3 für Gruppen mit dem Paket ggplot2
ggplot(data = data, aes(x = Lieblingsfarbe, label =..count.., fill = Geschlecht))+
       geom_bar()+
       scale_fill_manual(values = c("steelblue", "darkred"),labels = c("Männlich", "Weiblich"))+
       labs(y = "Häufigkeit", fill = "Geschlecht:")+
       geom_text(stat = "count", position = position_stack(vjust=0.5), color = "white")+
       ggtitle("Gestapeltes Säulendiagramm")+
       theme(plot.title = element_text(hjust = 0.5), legend.position = "bottom")
