## 6.4 Boxplots

data <- read.csv2("data.csv", na = "NA", dec = ",", header=TRUE)
data$Lieblingsfarbe <- as.factor(data$Lieblingsfarbe)
data$Geschlecht[data$Geschlecht == "0"] <- "Mann"
data$Geschlecht[data$Geschlecht == "1"] <- "Frau"
data$Geschlecht <- as.factor(data$Geschlecht)

# 6.4.1 mit baseR
boxplot(data$IQ)

# Aufgeteilt nach Geschlecht
boxplot(data$IQ~data$Geschlecht,
        ylab = "IQ", xlab = "Geschlecht",
        main = "IQ der Probanden")

# Aufgeteilt nacht Motivation
boxplot(data$Einkommen~data$Motivation,
        xlab = "Motivation", ylab = "Einkommen",
        main = "Einkommen und Motivation",
        col = c("pink", "deeppink3", "firebrick1", "red", "darkred"),
        names = c("keine", "wenig", "mittel", "viel", "sehr viel"))

# 6.4.2 mit dem Paket ggplot2
# (A) Einfacher Boxplot für IQ
ggplot(data, aes(y = IQ)) +
       geom_boxplot()

# (B) Geteilter Boxplot für IQ nach Gruppen
ggplot(data, aes(y = IQ, fill = Geschlecht)) +
       geom_boxplot()

# Angepasster Boxplot für Gruppen
ggplot(data, aes(x = Geschlecht, y = IQ, fill = Geschlecht)) +
       stat_boxplot(geom = "errorbar", width = 0.25, colour = "black") +
       geom_boxplot(notch = TRUE)+
       geom_jitter(size = 1)+
       scale_fill_manual(values = c("steelblue", "darkred"), labels = c("Männlich", "Weiblich"))
