## 7.2 Diagramme mit ggplot2
arbeit <- read.csv2("arbeit.csv", na="NA")
arbeit$Datum <- as.Date(arbeit$Datum, format = "%d.%m.%Y")

# 7.2.1 für 1 Variable
# Liniendiagramm
ggplot(data = arbeit, aes(x = Datum, y = Erwerbstätige..Mio.)) +
  geom_line()

# Liniendiagramm mit Datenpunkten
ggplot(data = arbeit, aes(x = Datum, y = Erwerbstätige..Mio.)) +
  geom_line(linetype = 2)+
  labs(x = "Datum", y = "Erwerbstätige in Mio.") +
  geom_point(size = 1.5, pch = 21, color = "black", bg = "grey")

# Angepasste x-Achse
ggplot(data = arbeit, aes(x = Datum, y = Erwerbstätige..Mio.)) +
  geom_line(linetype = 2)+
  labs(x = "Datum", y = "Erwerbstätige in Mio.") +
  geom_point(size = 1.5, pch = 21, color = "black", bg = "grey")+
  scale_x_date(date_breaks = "2 years", date_minor_breaks = "2 months", date_labels = "%Y")

# Ausschnitt
ggplot(data = arbeit, aes(x = Datum, y = Erwerbstätige..Mio.)) +
  geom_line(linetype = 2)+
  labs(x = "Datum", y = "Erwerbstätige in Mio.") +
  geom_point(size = 1.5, pch = 21, color = "black", bg = "grey")+
  scale_x_date(limits = as.Date(c("2008-01-01","2010-01-01")))

# 7.2.2 für >1 Variable
ggplot(data = arbeit, aes(x = Datum)) +
  geom_line(aes(y = Erwerbstätige..Mio.), linetype = 1, color = "darkgreen", size = 1)+
  geom_line(aes(y = Erwerbslose..Mio.), linetype = 2, size = 1)

# Legende in das Diagramm einfügen - Transformation in long-Format im Vorfeld notwendig  
arbeit_subset <- subset(arbeit, select=c(Datum,Erwerbstätige..Mio.,Erwerbslose..Mio.))
arbeit_long <- pivot_longer(arbeit_subset, Erwerbstätige..Mio.:Erwerbslose..Mio., names_to = "Kategorie", values_to = "Wert")
ggplot(data = arbeit_long, aes(x = Datum, y = Wert,color = Kategorie)) +
  geom_line(size = 0.75)+
  labs(x = "Datum", y = "Personen in Mio.")+
  theme(legend.position = "bottom")+
  scale_color_manual(name = "Legende", labels = c("Erwerbstätige","Erwerbslose"), values = c("darkgreen", "darkred"))+
  scale_linetype_manual(name = "Legende",labels = c("Erwerbstätige", "Erwerbslose"), values = c(1,1))

# 7.2.3 Gestaeltes Flächendiagramm
ggplot(arbeit_long, aes(x = Datum, y = Wert, fill = Kategorie))+
  geom_area(alpha = 0.3, size = 0.2, colour = "black")+
  labs(x = "Datum", y = "Personen in Mio.")+
  theme(legend.position = "bottom")+
  scale_fill_manual(name = "Legende", labels = c("Erwerbslose", "Erwerbstätige"), values = c("darkred", "darkgreen"))

# 7.2.4 Boxplots
    # Daten im long-Format einlesen
rep <- read_excel("reps.xlsx", na="NA", col_names=TRUE)
rep_long <- pivot_longer(rep, T0:T4, names_to="Zeitpunkt", values_to="Wert")
rep_long$Zeitpunkt <- as.factor(rep_long$Zeitpunkt)
    # Boxplots erstellen
ggplot(rep_long, aes(x = Zeitpunkt, y = Wert))+
       geom_boxplot()

# 7.2.5 Säulendiagramm mit Fehlerbalken
ggplot(rep_long, aes(x = Zeitpunkt, y = Wert))+
  geom_bar(stat = "summary", fun = "mean", fill = "steelblue")+
  stat_summary(fun.data = mean_sdl, fun.args = list(mult = 1), geom = "errorbar", color = "black", width = 0.5, size = 1)+
  stat_summary(fun = mean, geom = "point", color = "black",fill = "lightgrey", pch = 21, size = 3)

# 7.2.6 Liniendiagramm mit Fehlerbalken
install.packages("ggpubr")
library(ggpubr)
ggline(rep_long, x = "Zeitpunkt", y = "Wert", add = "mean_se")
